@@ -20,7 +20,21 @@ namespace facter { namespace facts { namespace linux {
          * @param facts The fact collection that is resolving facts.
          * @return Returns the name of the hypervisor or empty string if no hypervisor.
          */
-        virtual std::string get_hypervisor(collection& facts) override;
+        std::string get_hypervisor(collection& facts) override;
+        /**
+         * Gets the name of the cloud provider.
+         * @param facts The fact collection that is resolving facts.
+         * @return Returns the name of the cloud provider or empty string if no hypervisor.
+         */
+        std::string get_cloud_provider(collection& facts) override;
+
+        /**
+         * Gets whether the machine is running in Azure.
+         * @param facts The fact collection that is resolving facts.
+         * @param leases_file The location of where the leases file exists.
+         * @return Returns "azure" if running on azure, otherwise an empty string.
+         */
+        static std::string get_azure(collection& facts, std::string const& leases_file = "/var/lib/dhcp/dhclient.eth0.leases");
 
      private:
         static std::string get_cgroup_vm();
@@ -30,7 +44,6 @@ namespace facter { namespace facts { namespace linux {
         static std::string get_vmware_vm();
         static std::string get_openvz_vm();
         static std::string get_xen_vm();
-        static std::string get_product_name_vm(collection& facts);
         static std::string get_lspci_vm();
     };
 
