@@ -4,7 +4,7 @@
  */
 #pragma once
 
-#include <facter/util/scoped_resource.hpp>
+#include <leatherman/util/scoped_resource.hpp>
 #include <openssl/bio.h>
 
 namespace facter { namespace util { namespace posix {
@@ -13,13 +13,13 @@ namespace facter { namespace util { namespace posix {
      * Represents a scoped OpenSSL BIO object.
      * Automatically frees the BIO when it goes out of scope.
     */
-    struct scoped_bio : scoped_resource<BIO*>
+    struct scoped_bio : leatherman::util::scoped_resource<BIO*>
     {
         /**
          * Constructs a scoped_bio.
          * @param method The BIO_METHOD to use.
          */
-        explicit scoped_bio(BIO_METHOD* method);
+        explicit scoped_bio(const BIO_METHOD* method);
 
         /**
          * Constructs a scoped_bio.
