@@ -1,9 +1,9 @@
 #include <internal/facts/windows/dmi_resolver.hpp>
-#include <internal/util/windows/wmi.hpp>
+#include <leatherman/windows/wmi.hpp>
 #include <leatherman/logging/logging.hpp>
 
 using namespace std;
-using namespace facter::util::windows;
+using namespace leatherman::windows;
 
 namespace facter { namespace facts { namespace windows {
 
@@ -18,11 +18,19 @@ namespace facter { namespace facts { namespace windows {
         data result;
 
         auto vals = _wmi->query(wmi::computersystemproduct, {wmi::name});
-        result.product_name = wmi::get(vals, wmi::name);
+        if (vals.empty()) {
+            LOG_DEBUG("WMI query returned no results for {1} with value {2}.", wmi::computersystemproduct, wmi::name);
+        } else {
+            result.product_name = wmi::get(vals, wmi::name);
+        }
 
         vals = _wmi->query(wmi::bios, {wmi::manufacturer, wmi::serialnumber});
-        result.serial_number = wmi::get(vals, wmi::serialnumber);
-        result.manufacturer = wmi::get(vals, wmi::manufacturer);
+        if (vals.empty()) {
+            LOG_DEBUG("WMI query returned no results for {1} with values {2} and {3}.", wmi::bios, wmi::serialnumber, wmi::manufacturer);
+        } else {
+            result.serial_number = wmi::get(vals, wmi::serialnumber);
+            result.manufacturer = wmi::get(vals, wmi::manufacturer);
+        }
 
         return result;
     }
