@@ -4,13 +4,13 @@
 #include <facter/facts/array_value.hpp>
 #include <facter/facts/map_value.hpp>
 #include <facter/facts/scalar_value.hpp>
-#include <facter/util/environment.hpp>
+#include <leatherman/util/environment.hpp>
 #include "../fixtures.hpp"
 #include <sstream>
 
 using namespace std;
 using namespace facter::facts;
-using namespace facter::util;
+using namespace leatherman::util;
 using namespace facter::testing;
 
 struct simple_resolver : facter::facts::resolver
@@ -23,6 +23,28 @@ struct simple_resolver : facter::facts::resolver
     {
         facts.add("foo", make_value<string_value>("bar"));
     }
+
+    bool is_blockable() const override
+    {
+        return true;
+    }
+};
+
+struct unblockable_resolver : facter::facts::resolver
+{
+    unblockable_resolver() : resolver("unblockable", { "foo" })
+    {
+    }
+
+    virtual void resolve(collection& facts) override
+    {
+        facts.add("foo", make_value<string_value>("bar"));
+    }
+
+    bool is_blockable() const override
+    {
+        return false;
+    }
 };
 
 struct multi_resolver : facter::facts::resolver
@@ -36,6 +58,11 @@ struct multi_resolver : facter::facts::resolver
         facts.add("foo", make_value<string_value>("bar"));
         facts.add("bar", make_value<string_value>("foo"));
     }
+
+    bool is_blockable() const override
+    {
+        return true;
+    }
 };
 
 struct temp_variable
@@ -105,17 +132,17 @@ SCENARIO("using the fact collection") {
         WHEN("writing all (hidden) facts") {
             THEN("it should serialize both facts to JSON") {
                 ostringstream ss;
-                facts.write(ss, format::json, set<string>{}, true);
+                facts.write(ss, format::json, set<string>{}, true, false);
                 REQUIRE(ss.str() == "{\n  \"foo\": \"bar\",\n  \"hidden_foo\": \"hidden_bar\"\n}");
             }
             THEN("it should serialize both facts to YAML") {
                 ostringstream ss;
-                facts.write(ss, format::yaml, set<string>{}, true);
+                facts.write(ss, format::yaml, set<string>{}, true, false);
                 REQUIRE(ss.str() == "foo: bar\nhidden_foo: hidden_bar");
             }
             THEN("it should serialize both facts to text") {
                 ostringstream ss;
-                facts.write(ss, format::hash, set<string>{}, true);
+                facts.write(ss, format::hash, set<string>{}, true, false);
                 REQUIRE(ss.str() == "foo => bar\nhidden_foo => hidden_bar");
             }
         }
@@ -139,17 +166,17 @@ SCENARIO("using the fact collection") {
         WHEN("querying hidden facts") {
             THEN("it should serialize both facts to JSON") {
                 ostringstream ss;
-                facts.write(ss, format::json, {"foo", "hidden_foo"}, true);
+                facts.write(ss, format::json, {"foo", "hidden_foo"}, true, false);
                 REQUIRE(ss.str() == "{\n  \"foo\": \"bar\",\n  \"hidden_foo\": \"hidden_bar\"\n}");
             }
             THEN("it should serialize both facts to YAML") {
                 ostringstream ss;
-                facts.write(ss, format::yaml, {"foo", "hidden_foo"}, true);
+                facts.write(ss, format::yaml, {"foo", "hidden_foo"}, true, false);
                 REQUIRE(ss.str() == "foo: bar\nhidden_foo: hidden_bar");
             }
             THEN("it should serialize both facts to text") {
                 ostringstream ss;
-                facts.write(ss, format::hash, {"foo", "hidden_foo"}, true);
+                facts.write(ss, format::hash, {"foo", "hidden_foo"}, true, false);
                 REQUIRE(ss.str() == "foo => bar\nhidden_foo => hidden_bar");
             }
         }
@@ -246,7 +273,7 @@ SCENARIO("using the fact collection") {
                 LIBFACTER_TESTS_DIRECTORY "/fixtures/facts/external/text",
         });
         REQUIRE_FALSE(facts.empty());
-        REQUIRE(facts.size() == 17u);
+        REQUIRE(facts.size() == 20u);
         WHEN("YAML files are present") {
             THEN("facts should be added") {
                 REQUIRE(facts.get<string_value>("yaml_fact1"));
@@ -256,6 +283,9 @@ SCENARIO("using the fact collection") {
                 REQUIRE(facts.get<array_value>("yaml_fact5"));
                 REQUIRE(facts.get<map_value>("yaml_fact6"));
                 REQUIRE(facts.get<string_value>("yaml_fact7"));
+                REQUIRE(facts.get<string_value>("not_bool"));
+                REQUIRE(facts.get<string_value>("not_int"));
+                REQUIRE(facts.get<string_value>("not_double"));
             }
         }
         WHEN("JSON files are present") {
@@ -373,7 +403,7 @@ SCENARIO("using the fact collection") {
             }
         }
         WHEN("a fact name contains dots") {
-            THEN("it not reqturn a value unless quoted") {
+            THEN("it not return a value unless quoted") {
                 REQUIRE_FALSE(facts.query("map.name.with.dots"));
             }
             THEN("it should return a value when quoted") {
@@ -466,7 +496,7 @@ SCENARIO("using the fact collection with a default external fact path") {
             LIBFACTER_TESTS_DIRECTORY "/fixtures/facts/external/text",
         });
         REQUIRE_FALSE(facts.empty());
-        REQUIRE(facts.size() == 4);
+        REQUIRE(facts.size() == 4u);
         THEN("facts from both directories should be added") {
             REQUIRE(facts.get<string_value>("foo"));
             REQUIRE(facts.get<string_value>("txt_fact1"));
@@ -476,3 +506,71 @@ SCENARIO("using the fact collection with a default external fact path") {
         }
     }
 }
+
+SCENARIO("using the fact collection with a blocklist") {
+    collection_fixture facts({ "test" });
+    REQUIRE(facts.size() == 0u);
+    REQUIRE(facts.empty());
+
+    GIVEN("a resolver that adds a single fact") {
+        facts.add(make_shared<simple_resolver>());
+        THEN("the fact should not be resolved") {
+            REQUIRE(facts.size() == 0u);
+            REQUIRE_FALSE(facts.get<string_value>("foo"));
+        }
+    }
+    GIVEN("a resolver that adds multiple facts") {
+        facts.add(make_shared<multi_resolver>());
+        THEN("none of the facts should resolve") {
+            REQUIRE(facts.size() == 0u);
+            REQUIRE_FALSE(facts.get<string_value>("foo"));
+            REQUIRE_FALSE(facts.get<string_value>("bar"));
+        }
+    }
+}
+
+SCENARIO("querying blockable and cacheable fact groups") {
+    collection_fixture facts;
+    REQUIRE(facts.size() == 0u);
+    REQUIRE(facts.empty());
+
+    GIVEN("a blockable resolver that adds a single fact") {
+        facts.add(make_shared<simple_resolver>());
+        THEN("resolver and its fact should be listed as blockable") {
+            auto blockable = facts.get_blockable_fact_groups();
+            REQUIRE(blockable.size() == 1);
+            REQUIRE(blockable["test"] == vector<string>({"foo"}));
+        }
+        THEN("resolver and its fact should be listed as in the collection") {
+            auto facts_present = facts.get_fact_groups();
+            REQUIRE(facts_present.size() == 1);
+            REQUIRE(facts_present["test"] == vector<string>({"foo"}));
+        }
+    }
+    GIVEN("a blockable resolver that adds multiple facts") {
+        facts.add(make_shared<multi_resolver>());
+        THEN("resolver and its facts should be listed as blockable") {
+            auto blockable = facts.get_blockable_fact_groups();
+            REQUIRE(blockable.size() == 1);
+            REQUIRE(blockable["test"] == vector<string>({"foo", "bar"}));
+        }
+        THEN("resolver and its facts should be listed as in the collection") {
+            auto facts_present = facts.get_fact_groups();
+            REQUIRE(facts_present.size() == 1);
+            REQUIRE(facts_present["test"] == vector<string>({"foo", "bar"}));
+        }
+    }
+    GIVEN("a unblockable resolver that adds a single fact") {
+        facts.add(make_shared<unblockable_resolver>());
+        THEN("resolver and its facts should not be listed as blockable") {
+            auto blockable = facts.get_blockable_fact_groups();
+            REQUIRE(blockable.size() == 0);
+        }
+        THEN("resolver and its fact should be listed as in the collection") {
+            auto facts_present = facts.get_fact_groups();
+            REQUIRE(facts_present.size() == 1);
+            REQUIRE(facts_present["unblockable"] == vector<string>({"foo"}));
+        }
+    }
+
+}
